{% extends "otree/BaseAdmin.html" %}

{% block title %}
    Data Export
{% endblock %}


{% block content %}

    <div class="panel panel-primary">
      <div class="panel-heading">
        <h3 class="panel-title">Citation requirement</h3>
      </div>
      <div class="panel-body">
        <p>
        If you publish research conducted using oTree,
        you are required by the oTree license to cite <a href="http://dx.doi.org/10.1016/j.jbef.2015.12.001">this paper</a>.
        </p>
          <p>
              Citation:
          </p>
        <p>
            Chen, D.L., Schonger, M., Wickens, C., 2016. oTree - An open-source
            platform for laboratory, online and field experiments.
            Journal of Behavioral and Experimental Finance, vol 9: 88-97
        </p>

      </div>
    </div>

{% if apps %}
<table class="table">
    <thead>
        <tr>
            <th>App</th>
            <th>Data</th>
            <th>Documentation</th>
        </tr>
    </thead>
    <tbody>
    {% for app in apps %}
        <tr>
            <td>
                {{ app.name }}
            </td>
            <td>
                <a href="{% url 'ExportCsv' app.label %}"><span class="glyphicon glyphicon-download-alt"></span></a>
            </td>
            <td>
                <a href="{% url 'ExportAppDocs' app.label %}"><span class="glyphicon glyphicon-download-alt"></span></a>
            </td>
            <td>
            </td>
        </tr>
    {% endfor %}
    </tbody>
</table>
Time spent on each page can be downloaded <a href="{% url 'ExportTimeSpent' %}">here</a>.
{% else %}
<p>No sessions has yet taken place</p>
{% endif %}

<br/>
<br/>

{% endblock %}
